%Created By: Claire Weston
%Last Edited: 21 MAR 2011

% Front end for the blake 256 bit program, allows the user to enter
% message, salt value in to the system, the message can be either a binarye
% format or a hexadecimal format, the user specifes which with the radio
% button, the gui calls the blake256 function and passes the data in from
% the gui it returns the output to the gui
function front_end

    fh = figure('units','pixels',...
                  'position',[200 200 1000 500],...
                  'menubar','none',...
                  'name','BLAKE 256 Hash Function',...
                  'numbertitle','off',...
                  'resize','off');

    DigestTitle = uicontrol('style','text',...
                     'unit','pix',...
                     'position',[10 300 65 25],...
                     'min',0,'max',2,...
                     'fontsize',14,...
                     'BackgroundColor',[0.80 0.80 0.80],...
                     'string',{'Digest:'}); 
    DigestBox = uicontrol('style','list',...
                     'unit','pix',...
                     'position',[80 95 900 230],...
                     'min',0,'max',2,...
                     'fontsize',14,...
                     'backgroundColor',[1 1 1],...
                     'string',{''});         
    StartButton = uicontrol('style','push',...
                     'units','pix',...
                     'position',[800 350 180 40],...
                     'fontsize',14,...
                     'string',' Start ',...
                     'callback',{@StartButtonPressed});
    MessageTitle = uicontrol('style','text',...
                     'unit','pix',...
                     'position',[10 450 90 30],...
                     'fontsize',14,...
                     'backgroundColor',[0.8 0.8 0.8],...
                     'string','Message:');
    MessageBox = uicontrol('style','edit',...
                     'unit','pix',...
                     'position',[100 450 880 30],...
                     'fontsize',14,...
                     'backgroundColor',[1 1 1],...
                     'string','Enter data here');
    TimeElapsedTitle = uicontrol('style','text',...
                     'unit','pix',...
                     'position',[10 30 100 25],...
                     'fontsize',14,...
                     'BackgroundColor',[0.80 0.80 0.80],...
                     'string',{'Time taken:'}); 
    TimeElapsedBox = uicontrol('style','text',...
                     'unit','pix',...
                     'position',[115 30 110 30],...
                     'fontsize',14,...
                     'BackgroundColor',[1 1 1],...
                     'string',{''}); 
    TimeElapsedEnd = uicontrol('style','text',...
                     'unit','pix',...
                     'position',[230 20 50 25],...
                     'fontsize',10,...
                     'fontAngle','italic',...
                     'BackgroundColor',[0.80 0.80 0.80],...
                     'string',{'seconds'});
    TypeTitle = uicontrol('style','text',...
                     'unit','pix',...
                     'position',[10 400 90 30],...
                     'fontsize',14,...
                     'backgroundColor',[0.8 0.8 0.8],...
                     'string','Type:');
    TypeGroup = uibuttongroup('units','pix',...
                     'pos',[100 350 210 90]);
    Type(1) = uicontrol(TypeGroup,...
                    'style','rad',...
                    'unit','pix',...
                    'position',[20 50 90 30],...
                    'string','Binary');
    Type(2) = uicontrol(TypeGroup,...
                    'style','rad',...
                    'unit','pix',...
                    'position',[20 10 90 30],...
                    'string','hexadecimal');
    SaltTitle = uicontrol('style','text',...
                     'unit','pix',...
                     'position',[400 400 90 30],...
                     'fontsize',14,...
                     'backgroundColor',[0.8 0.8 0.8],...
                     'string','Salt:');
    SaltBox = uicontrol('style','edit',...
                     'unit','pix',...
                     'position',[475 405 150 30],...
                     'fontsize',14,...
                     'backgroundColor',[1 1 1],...
                     'string','Salt value');

    function StartButtonPressed (h,eventdata)
        set(StartButton,'string','RUNNING...');
        % The string to add to the stack
        MessageInput = {get(MessageBox,'string')};
        MessageInput=char(MessageInput);
        % The salt is recovered from the gui and transfered to a varaiable
        % passed in to the system
        Salt = {get(SaltBox,'string')};
        Salt = cell2mat(Salt);
        % Detect is input is binary or hex, by default type is set to
        % binnary
        type=1;
        switch findobj(get(TypeGroup,'selectedobject'))
            case Type(1)
                type = 1;
            case Type(2)
                type = 2;
        end
        % starts the timer to test how long blake 256 hash function takes
        StartTime=clock;
        % calls the blake 256 bit function function
        DigestOutput = BLAKE256(MessageInput,type,Salt);
        FinishTime = clock;
        DigestOutput = dec2hex(DigestOutput);
        DigestOutput = cellstr(DigestOutput);
        % set the output box text to the output from the algorithm
        set(DigestBox,'str',{DigestOutput{:}});
        % changes the start button text back to start to let the user know
        % they can submit another string in to the system
        set(StartButton,'string',' Start ');
        % calculates the time it took for the conversion of the string
        ElapsedTime=FinishTime-StartTime;
        ElapsedTime=ElapsedTime(6);
        ElapsedTime = num2str(ElapsedTime);
        ElapsedTime = cellstr(ElapsedTime);
        set(TimeElapsedBox,'string',ElapsedTime);
    end
                 
                 
end

